@@ -1,7 +1,7 @@
 #' @title Summarize results of LUCID model
 #'
-#' @param object A LUCID model fitted by \code{\link{est.lucid}}
-#' @param boot.se An object returned by \code{\link{boot.lucid}}, 
+#' @param object A LUCID model fitted by \code{\link{est_lucid}}
+#' @param boot.se An object returned by \code{\link{boot_lucid}}, 
 #' which contains the bootstrap confidence intervals
 #' 
 #' @export
@@ -13,11 +13,11 @@
 #' Y_normal <- sim_data$Y_normal
 #' 
 #' # fit lucid model
-#' fit1 <- est.lucid(G = G, Z = Z, Y = Y_normal, family = "normal", K = 2, 
+#' fit1 <- est_lucid(G = G, Z = Z, Y = Y_normal, family = "normal", K = 2, 
 #' seed = 1008)
 #' 
 #' # conduct bootstrap resampling
-#' boot1 <- boot.lucid(G = G, Z = Z, Y = Y_normal, model = fit1, R = 100)
+#' boot1 <- boot_lucid(G = G, Z = Z, Y = Y_normal, model = fit1, R = 100)
 #' 
 #' # summarize lucid model
 #' summary_lucid(fit1)
@@ -57,7 +57,7 @@ summary_lucid <- function(object, boot.se = NULL){
 
 #' Print the output of LUCID in a nicer table
 #'
-#' @param x An object returned by \code{summary.lucid}
+#' @param x An object returned by \code{summary_lucid}
 #' @param ... Other parameters to be passed to \code{print}
 #' @export
 #'
@@ -100,7 +100,7 @@ print.sumlucid <- function(x, ...){
 # summarize output of normal outcome
 f.normal <- function(x, K, se){
   
-  cat("(1) Y (normal outcome): mean of Y for each latent cluster (and effect of covariates if included) \n")
+  cat("(1) Y (continuous outcome): mean of Y for each latent cluster (and effect of covariates if included) \n")
   
   if(!is.null(se)){
     y <- se
